summaryrefslogtreecommitdiff
path: root/src/library
diff options
context:
space:
mode:
authorBurak Emir <emir@epfl.ch>2007-01-02 16:51:29 +0000
committerBurak Emir <emir@epfl.ch>2007-01-02 16:51:29 +0000
commitbfea9f20d231bc6b7fb75edbce277d883265b89d (patch)
tree97d1ad6e319e2dbc96edde4c906ae9668f82c7cb /src/library
parent9e3b5c094b4e8b96d418d7498deab78dcb8bf150 (diff)
downloadscala-bfea9f20d231bc6b7fb75edbce277d883265b89d.tar.gz
scala-bfea9f20d231bc6b7fb75edbce277d883265b89d.tar.bz2
scala-bfea9f20d231bc6b7fb75edbce277d883265b89d.zip
* TupleN extends ProductN, again (genprod updated)
* better comments and parameter names in scala.xml.MetaData typechecker * now handles special cases (n=0, n=1) for unapply correctly * * even if one returns a Option[Product1[T]] * typechecker now handles unapply return types correctly * * e.g. when returning Option[{A,B}] instead of Option[Product2[A,B]]
Diffstat (limited to 'src/library')
-rw-r--r--src/library/scala/Function0.scala2
-rw-r--r--src/library/scala/Function1.scala2
-rw-r--r--src/library/scala/Function2.scala2
-rw-r--r--src/library/scala/Function3.scala2
-rw-r--r--src/library/scala/Function4.scala2
-rw-r--r--src/library/scala/Function5.scala2
-rw-r--r--src/library/scala/Function6.scala2
-rw-r--r--src/library/scala/Function7.scala2
-rw-r--r--src/library/scala/Function8.scala2
-rw-r--r--src/library/scala/Product0.scala8
-rw-r--r--src/library/scala/Product1.scala10
-rw-r--r--src/library/scala/Product10.scala46
-rw-r--r--src/library/scala/Product11.scala50
-rw-r--r--src/library/scala/Product12.scala54
-rw-r--r--src/library/scala/Product13.scala58
-rw-r--r--src/library/scala/Product14.scala62
-rw-r--r--src/library/scala/Product15.scala66
-rw-r--r--src/library/scala/Product16.scala70
-rw-r--r--src/library/scala/Product17.scala74
-rw-r--r--src/library/scala/Product18.scala78
-rw-r--r--src/library/scala/Product19.scala82
-rw-r--r--src/library/scala/Product2.scala14
-rw-r--r--src/library/scala/Product20.scala86
-rw-r--r--src/library/scala/Product21.scala90
-rw-r--r--src/library/scala/Product22.scala94
-rw-r--r--src/library/scala/Product3.scala18
-rw-r--r--src/library/scala/Product4.scala22
-rw-r--r--src/library/scala/Product5.scala26
-rw-r--r--src/library/scala/Product6.scala30
-rw-r--r--src/library/scala/Product7.scala34
-rw-r--r--src/library/scala/Product8.scala38
-rw-r--r--src/library/scala/Product9.scala42
-rw-r--r--src/library/scala/Tuple1.scala5
-rw-r--r--src/library/scala/Tuple10.scala11
-rw-r--r--src/library/scala/Tuple11.scala11
-rw-r--r--src/library/scala/Tuple12.scala11
-rw-r--r--src/library/scala/Tuple13.scala11
-rw-r--r--src/library/scala/Tuple14.scala11
-rw-r--r--src/library/scala/Tuple15.scala11
-rw-r--r--src/library/scala/Tuple16.scala11
-rw-r--r--src/library/scala/Tuple17.scala11
-rw-r--r--src/library/scala/Tuple18.scala11
-rw-r--r--src/library/scala/Tuple19.scala11
-rw-r--r--src/library/scala/Tuple2.scala9
-rw-r--r--src/library/scala/Tuple20.scala11
-rw-r--r--src/library/scala/Tuple21.scala11
-rw-r--r--src/library/scala/Tuple22.scala11
-rw-r--r--src/library/scala/Tuple3.scala9
-rw-r--r--src/library/scala/Tuple4.scala9
-rw-r--r--src/library/scala/Tuple5.scala9
-rw-r--r--src/library/scala/Tuple6.scala9
-rw-r--r--src/library/scala/Tuple7.scala9
-rw-r--r--src/library/scala/Tuple8.scala9
-rw-r--r--src/library/scala/Tuple9.scala9
-rw-r--r--src/library/scala/xml/MetaData.scala43
-rw-r--r--src/library/scala/xml/UnprefixedAttribute.scala4
56 files changed, 737 insertions, 700 deletions
diff --git a/src/library/scala/Function0.scala b/src/library/scala/Function0.scala
index 5893a2b003..0f1dd97c7a 100644
--- a/src/library/scala/Function0.scala
+++ b/src/library/scala/Function0.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006 (with fancy comment)
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007 (with fancy comment)
package scala
diff --git a/src/library/scala/Function1.scala b/src/library/scala/Function1.scala
index d30e460988..9fba8ac7da 100644
--- a/src/library/scala/Function1.scala
+++ b/src/library/scala/Function1.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006 (with fancy comment) (with extra methods)
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007 (with fancy comment) (with extra methods)
package scala
diff --git a/src/library/scala/Function2.scala b/src/library/scala/Function2.scala
index b75c53e16c..8f8344a40d 100644
--- a/src/library/scala/Function2.scala
+++ b/src/library/scala/Function2.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006 (with fancy comment)
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007 (with fancy comment)
package scala
diff --git a/src/library/scala/Function3.scala b/src/library/scala/Function3.scala
index a65ba321cb..556f96098f 100644
--- a/src/library/scala/Function3.scala
+++ b/src/library/scala/Function3.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
diff --git a/src/library/scala/Function4.scala b/src/library/scala/Function4.scala
index 86851c2932..8c6d347f97 100644
--- a/src/library/scala/Function4.scala
+++ b/src/library/scala/Function4.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
diff --git a/src/library/scala/Function5.scala b/src/library/scala/Function5.scala
index 125b6b51a2..3c9b3b51ad 100644
--- a/src/library/scala/Function5.scala
+++ b/src/library/scala/Function5.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
diff --git a/src/library/scala/Function6.scala b/src/library/scala/Function6.scala
index 088c4eef84..a86b1b1fa4 100644
--- a/src/library/scala/Function6.scala
+++ b/src/library/scala/Function6.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
diff --git a/src/library/scala/Function7.scala b/src/library/scala/Function7.scala
index 6c6afae342..c799ed2f4e 100644
--- a/src/library/scala/Function7.scala
+++ b/src/library/scala/Function7.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
diff --git a/src/library/scala/Function8.scala b/src/library/scala/Function8.scala
index b569ffc34a..407ec171e0 100644
--- a/src/library/scala/Function8.scala
+++ b/src/library/scala/Function8.scala
@@ -9,7 +9,7 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
diff --git a/src/library/scala/Product0.scala b/src/library/scala/Product0.scala
index 16ff7f6640..2072a13d4a 100644
--- a/src/library/scala/Product0.scala
+++ b/src/library/scala/Product0.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product0 {
- def unapply(x:Any): Option[Product0] =
- if(x.isInstanceOf[Product0]) Some(x.asInstanceOf[Product0]) else None
+ def unapply(x: Product0): Some[Product0] =
+ Some(x)
}
/** Product0 is a cartesian product of 0 components
diff --git a/src/library/scala/Product1.scala b/src/library/scala/Product1.scala
index d02aab7b7a..7b771decec 100644
--- a/src/library/scala/Product1.scala
+++ b/src/library/scala/Product1.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product1 {
- def unapply[T1](x:Any): Option[Product1[T1]] =
- if(x.isInstanceOf[Product1[T1]]) Some(x.asInstanceOf[Product1[T1]]) else None
+ def unapply[T1](x: Product1[T1]): Some[Product1[T1]] =
+ Some(x)
}
/** Product1 is a cartesian product of 1 components
@@ -44,7 +44,7 @@ trait Product1[+T1] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
}
diff --git a/src/library/scala/Product10.scala b/src/library/scala/Product10.scala
index 0d370573ef..90c53a5812 100644
--- a/src/library/scala/Product10.scala
+++ b/src/library/scala/Product10.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product10 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10](x:Any): Option[Product10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]] =
- if(x.isInstanceOf[Product10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]]) Some(x.asInstanceOf[Product10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10](x: Product10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]): Some[Product10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]] =
+ Some(x)
}
/** Product10 is a cartesian product of 10 components
@@ -53,34 +53,34 @@ trait Product10[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10] extends Produ
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
}
diff --git a/src/library/scala/Product11.scala b/src/library/scala/Product11.scala
index 523ddbab39..24292124bb 100644
--- a/src/library/scala/Product11.scala
+++ b/src/library/scala/Product11.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product11 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11](x:Any): Option[Product11[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11]] =
- if(x.isInstanceOf[Product11[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11]]) Some(x.asInstanceOf[Product11[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11](x: Product11[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11]): Some[Product11[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11]] =
+ Some(x)
}
/** Product11 is a cartesian product of 11 components
@@ -54,37 +54,37 @@ trait Product11[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11] extends
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
}
diff --git a/src/library/scala/Product12.scala b/src/library/scala/Product12.scala
index 31d5d95ef0..7542e2c430 100644
--- a/src/library/scala/Product12.scala
+++ b/src/library/scala/Product12.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product12 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12](x:Any): Option[Product12[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12]] =
- if(x.isInstanceOf[Product12[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12]]) Some(x.asInstanceOf[Product12[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12](x: Product12[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12]): Some[Product12[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12]] =
+ Some(x)
}
/** Product12 is a cartesian product of 12 components
@@ -55,40 +55,40 @@ trait Product12[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12] e
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
}
diff --git a/src/library/scala/Product13.scala b/src/library/scala/Product13.scala
index b82c0ce277..5b63efd66b 100644
--- a/src/library/scala/Product13.scala
+++ b/src/library/scala/Product13.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product13 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13](x:Any): Option[Product13[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13]] =
- if(x.isInstanceOf[Product13[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13]]) Some(x.asInstanceOf[Product13[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13](x: Product13[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13]): Some[Product13[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13]] =
+ Some(x)
}
/** Product13 is a cartesian product of 13 components
@@ -56,43 +56,43 @@ trait Product13[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
}
diff --git a/src/library/scala/Product14.scala b/src/library/scala/Product14.scala
index 1568ceaccf..ddf9008fe4 100644
--- a/src/library/scala/Product14.scala
+++ b/src/library/scala/Product14.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product14 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14](x:Any): Option[Product14[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14]] =
- if(x.isInstanceOf[Product14[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14]]) Some(x.asInstanceOf[Product14[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14](x: Product14[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14]): Some[Product14[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14]] =
+ Some(x)
}
/** Product14 is a cartesian product of 14 components
@@ -57,46 +57,46 @@ trait Product14[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
}
diff --git a/src/library/scala/Product15.scala b/src/library/scala/Product15.scala
index 033f097f76..975ae54acd 100644
--- a/src/library/scala/Product15.scala
+++ b/src/library/scala/Product15.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product15 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15](x:Any): Option[Product15[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15]] =
- if(x.isInstanceOf[Product15[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15]]) Some(x.asInstanceOf[Product15[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15](x: Product15[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15]): Some[Product15[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15]] =
+ Some(x)
}
/** Product15 is a cartesian product of 15 components
@@ -58,49 +58,49 @@ trait Product15[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
}
diff --git a/src/library/scala/Product16.scala b/src/library/scala/Product16.scala
index 13fdea6f1f..4d0b84046c 100644
--- a/src/library/scala/Product16.scala
+++ b/src/library/scala/Product16.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product16 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16](x:Any): Option[Product16[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16]] =
- if(x.isInstanceOf[Product16[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16]]) Some(x.asInstanceOf[Product16[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16](x: Product16[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16]): Some[Product16[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16]] =
+ Some(x)
}
/** Product16 is a cartesian product of 16 components
@@ -59,52 +59,52 @@ trait Product16[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
- /** projection of this product */
- def _16:T16
+/** projection of this product */
+ def _16: T16
}
diff --git a/src/library/scala/Product17.scala b/src/library/scala/Product17.scala
index a575a3097a..c25556701b 100644
--- a/src/library/scala/Product17.scala
+++ b/src/library/scala/Product17.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product17 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17](x:Any): Option[Product17[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17]] =
- if(x.isInstanceOf[Product17[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17]]) Some(x.asInstanceOf[Product17[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17](x: Product17[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17]): Some[Product17[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17]] =
+ Some(x)
}
/** Product17 is a cartesian product of 17 components
@@ -60,55 +60,55 @@ trait Product17[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
- /** projection of this product */
- def _16:T16
+/** projection of this product */
+ def _16: T16
- /** projection of this product */
- def _17:T17
+/** projection of this product */
+ def _17: T17
}
diff --git a/src/library/scala/Product18.scala b/src/library/scala/Product18.scala
index f94478af79..36719fba7e 100644
--- a/src/library/scala/Product18.scala
+++ b/src/library/scala/Product18.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product18 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18](x:Any): Option[Product18[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18]] =
- if(x.isInstanceOf[Product18[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18]]) Some(x.asInstanceOf[Product18[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18](x: Product18[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18]): Some[Product18[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18]] =
+ Some(x)
}
/** Product18 is a cartesian product of 18 components
@@ -61,58 +61,58 @@ trait Product18[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
- /** projection of this product */
- def _16:T16
+/** projection of this product */
+ def _16: T16
- /** projection of this product */
- def _17:T17
+/** projection of this product */
+ def _17: T17
- /** projection of this product */
- def _18:T18
+/** projection of this product */
+ def _18: T18
}
diff --git a/src/library/scala/Product19.scala b/src/library/scala/Product19.scala
index 1bd2d9d23f..2cf7305d9f 100644
--- a/src/library/scala/Product19.scala
+++ b/src/library/scala/Product19.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product19 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19](x:Any): Option[Product19[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19]] =
- if(x.isInstanceOf[Product19[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19]]) Some(x.asInstanceOf[Product19[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19](x: Product19[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19]): Some[Product19[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19]] =
+ Some(x)
}
/** Product19 is a cartesian product of 19 components
@@ -62,61 +62,61 @@ trait Product19[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
- /** projection of this product */
- def _16:T16
+/** projection of this product */
+ def _16: T16
- /** projection of this product */
- def _17:T17
+/** projection of this product */
+ def _17: T17
- /** projection of this product */
- def _18:T18
+/** projection of this product */
+ def _18: T18
- /** projection of this product */
- def _19:T19
+/** projection of this product */
+ def _19: T19
}
diff --git a/src/library/scala/Product2.scala b/src/library/scala/Product2.scala
index 73da6ba66e..0cf2606e2d 100644
--- a/src/library/scala/Product2.scala
+++ b/src/library/scala/Product2.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product2 {
- def unapply[T1, T2](x:Any): Option[Product2[T1, T2]] =
- if(x.isInstanceOf[Product2[T1, T2]]) Some(x.asInstanceOf[Product2[T1, T2]]) else None
+ def unapply[T1, T2](x: Product2[T1, T2]): Some[Product2[T1, T2]] =
+ Some(x)
}
/** Product2 is a cartesian product of 2 components
@@ -45,10 +45,10 @@ trait Product2[+T1, +T2] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
}
diff --git a/src/library/scala/Product20.scala b/src/library/scala/Product20.scala
index 725e541e1d..8bcd5fa75e 100644
--- a/src/library/scala/Product20.scala
+++ b/src/library/scala/Product20.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product20 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20](x:Any): Option[Product20[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20]] =
- if(x.isInstanceOf[Product20[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20]]) Some(x.asInstanceOf[Product20[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20](x: Product20[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20]): Some[Product20[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20]] =
+ Some(x)
}
/** Product20 is a cartesian product of 20 components
@@ -63,64 +63,64 @@ trait Product20[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
- /** projection of this product */
- def _16:T16
+/** projection of this product */
+ def _16: T16
- /** projection of this product */
- def _17:T17
+/** projection of this product */
+ def _17: T17
- /** projection of this product */
- def _18:T18
+/** projection of this product */
+ def _18: T18
- /** projection of this product */
- def _19:T19
+/** projection of this product */
+ def _19: T19
- /** projection of this product */
- def _20:T20
+/** projection of this product */
+ def _20: T20
}
diff --git a/src/library/scala/Product21.scala b/src/library/scala/Product21.scala
index 237883838a..0d395c599c 100644
--- a/src/library/scala/Product21.scala
+++ b/src/library/scala/Product21.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product21 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21](x:Any): Option[Product21[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21]] =
- if(x.isInstanceOf[Product21[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21]]) Some(x.asInstanceOf[Product21[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21](x: Product21[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21]): Some[Product21[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21]] =
+ Some(x)
}
/** Product21 is a cartesian product of 21 components
@@ -64,67 +64,67 @@ trait Product21[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
- /** projection of this product */
- def _16:T16
+/** projection of this product */
+ def _16: T16
- /** projection of this product */
- def _17:T17
+/** projection of this product */
+ def _17: T17
- /** projection of this product */
- def _18:T18
+/** projection of this product */
+ def _18: T18
- /** projection of this product */
- def _19:T19
+/** projection of this product */
+ def _19: T19
- /** projection of this product */
- def _20:T20
+/** projection of this product */
+ def _20: T20
- /** projection of this product */
- def _21:T21
+/** projection of this product */
+ def _21: T21
}
diff --git a/src/library/scala/Product22.scala b/src/library/scala/Product22.scala
index 6292fed13f..ee31064964 100644
--- a/src/library/scala/Product22.scala
+++ b/src/library/scala/Product22.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product22 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22](x:Any): Option[Product22[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22]] =
- if(x.isInstanceOf[Product22[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22]]) Some(x.asInstanceOf[Product22[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22](x: Product22[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22]): Some[Product22[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22]] =
+ Some(x)
}
/** Product22 is a cartesian product of 22 components
@@ -65,70 +65,70 @@ trait Product22[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
- /** projection of this product */
- def _10:T10
+/** projection of this product */
+ def _10: T10
- /** projection of this product */
- def _11:T11
+/** projection of this product */
+ def _11: T11
- /** projection of this product */
- def _12:T12
+/** projection of this product */
+ def _12: T12
- /** projection of this product */
- def _13:T13
+/** projection of this product */
+ def _13: T13
- /** projection of this product */
- def _14:T14
+/** projection of this product */
+ def _14: T14
- /** projection of this product */
- def _15:T15
+/** projection of this product */
+ def _15: T15
- /** projection of this product */
- def _16:T16
+/** projection of this product */
+ def _16: T16
- /** projection of this product */
- def _17:T17
+/** projection of this product */
+ def _17: T17
- /** projection of this product */
- def _18:T18
+/** projection of this product */
+ def _18: T18
- /** projection of this product */
- def _19:T19
+/** projection of this product */
+ def _19: T19
- /** projection of this product */
- def _20:T20
+/** projection of this product */
+ def _20: T20
- /** projection of this product */
- def _21:T21
+/** projection of this product */
+ def _21: T21
- /** projection of this product */
- def _22:T22
+/** projection of this product */
+ def _22: T22
}
diff --git a/src/library/scala/Product3.scala b/src/library/scala/Product3.scala
index d67b09c46b..b27886f4a4 100644
--- a/src/library/scala/Product3.scala
+++ b/src/library/scala/Product3.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product3 {
- def unapply[T1, T2, T3](x:Any): Option[Product3[T1, T2, T3]] =
- if(x.isInstanceOf[Product3[T1, T2, T3]]) Some(x.asInstanceOf[Product3[T1, T2, T3]]) else None
+ def unapply[T1, T2, T3](x: Product3[T1, T2, T3]): Some[Product3[T1, T2, T3]] =
+ Some(x)
}
/** Product3 is a cartesian product of 3 components
@@ -46,13 +46,13 @@ trait Product3[+T1, +T2, +T3] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
}
diff --git a/src/library/scala/Product4.scala b/src/library/scala/Product4.scala
index ac98f6a9b9..fbfd8e6ac8 100644
--- a/src/library/scala/Product4.scala
+++ b/src/library/scala/Product4.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product4 {
- def unapply[T1, T2, T3, T4](x:Any): Option[Product4[T1, T2, T3, T4]] =
- if(x.isInstanceOf[Product4[T1, T2, T3, T4]]) Some(x.asInstanceOf[Product4[T1, T2, T3, T4]]) else None
+ def unapply[T1, T2, T3, T4](x: Product4[T1, T2, T3, T4]): Some[Product4[T1, T2, T3, T4]] =
+ Some(x)
}
/** Product4 is a cartesian product of 4 components
@@ -47,16 +47,16 @@ trait Product4[+T1, +T2, +T3, +T4] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
}
diff --git a/src/library/scala/Product5.scala b/src/library/scala/Product5.scala
index 1a72a21af7..362acc377e 100644
--- a/src/library/scala/Product5.scala
+++ b/src/library/scala/Product5.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product5 {
- def unapply[T1, T2, T3, T4, T5](x:Any): Option[Product5[T1, T2, T3, T4, T5]] =
- if(x.isInstanceOf[Product5[T1, T2, T3, T4, T5]]) Some(x.asInstanceOf[Product5[T1, T2, T3, T4, T5]]) else None
+ def unapply[T1, T2, T3, T4, T5](x: Product5[T1, T2, T3, T4, T5]): Some[Product5[T1, T2, T3, T4, T5]] =
+ Some(x)
}
/** Product5 is a cartesian product of 5 components
@@ -48,19 +48,19 @@ trait Product5[+T1, +T2, +T3, +T4, +T5] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
}
diff --git a/src/library/scala/Product6.scala b/src/library/scala/Product6.scala
index 0e125653c3..4ec0479ae8 100644
--- a/src/library/scala/Product6.scala
+++ b/src/library/scala/Product6.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product6 {
- def unapply[T1, T2, T3, T4, T5, T6](x:Any): Option[Product6[T1, T2, T3, T4, T5, T6]] =
- if(x.isInstanceOf[Product6[T1, T2, T3, T4, T5, T6]]) Some(x.asInstanceOf[Product6[T1, T2, T3, T4, T5, T6]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6](x: Product6[T1, T2, T3, T4, T5, T6]): Some[Product6[T1, T2, T3, T4, T5, T6]] =
+ Some(x)
}
/** Product6 is a cartesian product of 6 components
@@ -49,22 +49,22 @@ trait Product6[+T1, +T2, +T3, +T4, +T5, +T6] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
}
diff --git a/src/library/scala/Product7.scala b/src/library/scala/Product7.scala
index 1bf22f9a99..e9a131e758 100644
--- a/src/library/scala/Product7.scala
+++ b/src/library/scala/Product7.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product7 {
- def unapply[T1, T2, T3, T4, T5, T6, T7](x:Any): Option[Product7[T1, T2, T3, T4, T5, T6, T7]] =
- if(x.isInstanceOf[Product7[T1, T2, T3, T4, T5, T6, T7]]) Some(x.asInstanceOf[Product7[T1, T2, T3, T4, T5, T6, T7]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7](x: Product7[T1, T2, T3, T4, T5, T6, T7]): Some[Product7[T1, T2, T3, T4, T5, T6, T7]] =
+ Some(x)
}
/** Product7 is a cartesian product of 7 components
@@ -50,25 +50,25 @@ trait Product7[+T1, +T2, +T3, +T4, +T5, +T6, +T7] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
}
diff --git a/src/library/scala/Product8.scala b/src/library/scala/Product8.scala
index dc82849a53..79c73fd892 100644
--- a/src/library/scala/Product8.scala
+++ b/src/library/scala/Product8.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product8 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8](x:Any): Option[Product8[T1, T2, T3, T4, T5, T6, T7, T8]] =
- if(x.isInstanceOf[Product8[T1, T2, T3, T4, T5, T6, T7, T8]]) Some(x.asInstanceOf[Product8[T1, T2, T3, T4, T5, T6, T7, T8]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8](x: Product8[T1, T2, T3, T4, T5, T6, T7, T8]): Some[Product8[T1, T2, T3, T4, T5, T6, T7, T8]] =
+ Some(x)
}
/** Product8 is a cartesian product of 8 components
@@ -51,28 +51,28 @@ trait Product8[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
}
diff --git a/src/library/scala/Product9.scala b/src/library/scala/Product9.scala
index ebe198943b..c0b4bda89a 100644
--- a/src/library/scala/Product9.scala
+++ b/src/library/scala/Product9.scala
@@ -7,17 +7,17 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
import Predef._
object Product9 {
- def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9](x:Any): Option[Product9[T1, T2, T3, T4, T5, T6, T7, T8, T9]] =
- if(x.isInstanceOf[Product9[T1, T2, T3, T4, T5, T6, T7, T8, T9]]) Some(x.asInstanceOf[Product9[T1, T2, T3, T4, T5, T6, T7, T8, T9]]) else None
+ def unapply[T1, T2, T3, T4, T5, T6, T7, T8, T9](x: Product9[T1, T2, T3, T4, T5, T6, T7, T8, T9]): Some[Product9[T1, T2, T3, T4, T5, T6, T7, T8, T9]] =
+ Some(x)
}
/** Product9 is a cartesian product of 9 components
@@ -52,31 +52,31 @@ trait Product9[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9] extends Product {
}
/** projection of this product */
- def _1:T1
+ def _1: T1
- /** projection of this product */
- def _2:T2
+/** projection of this product */
+ def _2: T2
- /** projection of this product */
- def _3:T3
+/** projection of this product */
+ def _3: T3
- /** projection of this product */
- def _4:T4
+/** projection of this product */
+ def _4: T4
- /** projection of this product */
- def _5:T5
+/** projection of this product */
+ def _5: T5
- /** projection of this product */
- def _6:T6
+/** projection of this product */
+ def _6: T6
- /** projection of this product */
- def _7:T7
+/** projection of this product */
+ def _7: T7
- /** projection of this product */
- def _8:T8
+/** projection of this product */
+ def _8: T8
- /** projection of this product */
- def _9:T9
+/** projection of this product */
+ def _9: T9
}
diff --git a/src/library/scala/Tuple1.scala b/src/library/scala/Tuple1.scala
index 338ed18db9..436f6b4ab9 100644
--- a/src/library/scala/Tuple1.scala
+++ b/src/library/scala/Tuple1.scala
@@ -9,12 +9,13 @@
// $Id$
-// generated by genprod on Tue Dec 12 14:11:19 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple1 is the canonical representation of a @see Product1 */
-case class Tuple1[+T1](_1:T1) {
+case class Tuple1[+T1](_1:T1)
+ extends Product1[T1] {
override def toString() = {
val sb = new compat.StringBuilder
diff --git a/src/library/scala/Tuple10.scala b/src/library/scala/Tuple10.scala
index 6ea91506ed..20c6032c31 100644
--- a/src/library/scala/Tuple10.scala
+++ b/src/library/scala/Tuple10.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple10 is the canonical representation of a @see Product10 */
-case class Tuple10[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10) {
+case class Tuple10[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10)
+ extends Product10[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple11.scala b/src/library/scala/Tuple11.scala
index 4377514444..4510d99db3 100644
--- a/src/library/scala/Tuple11.scala
+++ b/src/library/scala/Tuple11.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple11 is the canonical representation of a @see Product11 */
-case class Tuple11[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11) {
+case class Tuple11[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11)
+ extends Product11[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple12.scala b/src/library/scala/Tuple12.scala
index 1eed8804f5..5362db6bbf 100644
--- a/src/library/scala/Tuple12.scala
+++ b/src/library/scala/Tuple12.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple12 is the canonical representation of a @see Product12 */
-case class Tuple12[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12) {
+case class Tuple12[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12)
+ extends Product12[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple13.scala b/src/library/scala/Tuple13.scala
index 363cc618f1..d0eaff1db7 100644
--- a/src/library/scala/Tuple13.scala
+++ b/src/library/scala/Tuple13.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple13 is the canonical representation of a @see Product13 */
-case class Tuple13[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13) {
+case class Tuple13[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13)
+ extends Product13[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple14.scala b/src/library/scala/Tuple14.scala
index 116879a444..9827230e3e 100644
--- a/src/library/scala/Tuple14.scala
+++ b/src/library/scala/Tuple14.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple14 is the canonical representation of a @see Product14 */
-case class Tuple14[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14) {
+case class Tuple14[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14)
+ extends Product14[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple15.scala b/src/library/scala/Tuple15.scala
index c6989fc155..153c12d9ab 100644
--- a/src/library/scala/Tuple15.scala
+++ b/src/library/scala/Tuple15.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple15 is the canonical representation of a @see Product15 */
-case class Tuple15[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15) {
+case class Tuple15[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15)
+ extends Product15[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple16.scala b/src/library/scala/Tuple16.scala
index 6308d91525..ce5c9f3fca 100644
--- a/src/library/scala/Tuple16.scala
+++ b/src/library/scala/Tuple16.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple16 is the canonical representation of a @see Product16 */
-case class Tuple16[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16) {
+case class Tuple16[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16)
+ extends Product16[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple17.scala b/src/library/scala/Tuple17.scala
index b3e76bbaf2..c17726db12 100644
--- a/src/library/scala/Tuple17.scala
+++ b/src/library/scala/Tuple17.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple17 is the canonical representation of a @see Product17 */
-case class Tuple17[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17) {
+case class Tuple17[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17)
+ extends Product17[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple18.scala b/src/library/scala/Tuple18.scala
index 8152bfbfa9..4eca8e5645 100644
--- a/src/library/scala/Tuple18.scala
+++ b/src/library/scala/Tuple18.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple18 is the canonical representation of a @see Product18 */
-case class Tuple18[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18) {
+case class Tuple18[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18)
+ extends Product18[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple19.scala b/src/library/scala/Tuple19.scala
index e4dfc79852..49344df57d 100644
--- a/src/library/scala/Tuple19.scala
+++ b/src/library/scala/Tuple19.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple19 is the canonical representation of a @see Product19 */
-case class Tuple19[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19) {
+case class Tuple19[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19)
+ extends Product19[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple2.scala b/src/library/scala/Tuple2.scala
index 4c8aba5d81..ad5e5cf040 100644
--- a/src/library/scala/Tuple2.scala
+++ b/src/library/scala/Tuple2.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple2 is the canonical representation of a @see Product2 */
-case class Tuple2[+T1, +T2](_1:T1, _2:T2) {
+case class Tuple2[+T1, +T2](_1:T1, _2:T2)
+ extends Product2[T1, T2] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple20.scala b/src/library/scala/Tuple20.scala
index b4a7f1b9b1..59c99e1791 100644
--- a/src/library/scala/Tuple20.scala
+++ b/src/library/scala/Tuple20.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple20 is the canonical representation of a @see Product20 */
-case class Tuple20[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19, +T20](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19, _20:T20) {
+case class Tuple20[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19, +T20](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19, _20:T20)
+ extends Product20[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append(',').append(_20).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append(',').append(_20).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple21.scala b/src/library/scala/Tuple21.scala
index 349e15d980..aa33d4bda1 100644
--- a/src/library/scala/Tuple21.scala
+++ b/src/library/scala/Tuple21.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple21 is the canonical representation of a @see Product21 */
-case class Tuple21[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19, +T20, +T21](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19, _20:T20, _21:T21) {
+case class Tuple21[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19, +T20, +T21](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19, _20:T20, _21:T21)
+ extends Product21[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append(',').append(_20).append(',').append(_21).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append(',').append(_20).append(',').append(_21).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple22.scala b/src/library/scala/Tuple22.scala
index d2f948123e..dbd8291cc9 100644
--- a/src/library/scala/Tuple22.scala
+++ b/src/library/scala/Tuple22.scala
@@ -7,18 +7,19 @@
** |/ **
\* */
-// $Id: genprod.scala 9494 2006-12-11 11:35:38Z odersky $
+// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple22 is the canonical representation of a @see Product22 */
-case class Tuple22[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19, +T20, +T21, +T22](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19, _20:T20, _21:T21, _22:T22) {
+case class Tuple22[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9, +T10, +T11, +T12, +T13, +T14, +T15, +T16, +T17, +T18, +T19, +T20, +T21, +T22](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9, _10:T10, _11:T11, _12:T12, _13:T13, _14:T14, _15:T15, _16:T16, _17:T17, _18:T18, _19:T19, _20:T20, _21:T21, _22:T22)
+ extends Product22[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append(',').append(_20).append(',').append(_21).append(',').append(_22).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append(',').append(_10).append(',').append(_11).append(',').append(_12).append(',').append(_13).append(',').append(_14).append(',').append(_15).append(',').append(_16).append(',').append(_17).append(',').append(_18).append(',').append(_19).append(',').append(_20).append(',').append(_21).append(',').append(_22).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple3.scala b/src/library/scala/Tuple3.scala
index e0ebdafd55..8fc6bafbaf 100644
--- a/src/library/scala/Tuple3.scala
+++ b/src/library/scala/Tuple3.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple3 is the canonical representation of a @see Product3 */
-case class Tuple3[+T1, +T2, +T3](_1:T1, _2:T2, _3:T3) {
+case class Tuple3[+T1, +T2, +T3](_1:T1, _2:T2, _3:T3)
+ extends Product3[T1, T2, T3] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple4.scala b/src/library/scala/Tuple4.scala
index ad8489ec73..fc711ade78 100644
--- a/src/library/scala/Tuple4.scala
+++ b/src/library/scala/Tuple4.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple4 is the canonical representation of a @see Product4 */
-case class Tuple4[+T1, +T2, +T3, +T4](_1:T1, _2:T2, _3:T3, _4:T4) {
+case class Tuple4[+T1, +T2, +T3, +T4](_1:T1, _2:T2, _3:T3, _4:T4)
+ extends Product4[T1, T2, T3, T4] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple5.scala b/src/library/scala/Tuple5.scala
index 452ae46d3f..78ec034b5b 100644
--- a/src/library/scala/Tuple5.scala
+++ b/src/library/scala/Tuple5.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple5 is the canonical representation of a @see Product5 */
-case class Tuple5[+T1, +T2, +T3, +T4, +T5](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5) {
+case class Tuple5[+T1, +T2, +T3, +T4, +T5](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5)
+ extends Product5[T1, T2, T3, T4, T5] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple6.scala b/src/library/scala/Tuple6.scala
index 5b3a40e63a..52afb2435b 100644
--- a/src/library/scala/Tuple6.scala
+++ b/src/library/scala/Tuple6.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple6 is the canonical representation of a @see Product6 */
-case class Tuple6[+T1, +T2, +T3, +T4, +T5, +T6](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6) {
+case class Tuple6[+T1, +T2, +T3, +T4, +T5, +T6](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6)
+ extends Product6[T1, T2, T3, T4, T5, T6] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple7.scala b/src/library/scala/Tuple7.scala
index a5c0243b0e..82c4abdb7b 100644
--- a/src/library/scala/Tuple7.scala
+++ b/src/library/scala/Tuple7.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple7 is the canonical representation of a @see Product7 */
-case class Tuple7[+T1, +T2, +T3, +T4, +T5, +T6, +T7](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7) {
+case class Tuple7[+T1, +T2, +T3, +T4, +T5, +T6, +T7](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7)
+ extends Product7[T1, T2, T3, T4, T5, T6, T7] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple8.scala b/src/library/scala/Tuple8.scala
index 1db7653311..3d42463312 100644
--- a/src/library/scala/Tuple8.scala
+++ b/src/library/scala/Tuple8.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple8 is the canonical representation of a @see Product8 */
-case class Tuple8[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8) {
+case class Tuple8[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8)
+ extends Product8[T1, T2, T3, T4, T5, T6, T7, T8] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/Tuple9.scala b/src/library/scala/Tuple9.scala
index 2b467696f7..c5c27eaade 100644
--- a/src/library/scala/Tuple9.scala
+++ b/src/library/scala/Tuple9.scala
@@ -9,16 +9,17 @@
// $Id$
-// generated by genprod on Tue Dec 12 11:32:13 CET 2006
+// generated by genprod on Tue Jan 02 15:19:32 CET 2007
package scala
/** Tuple9 is the canonical representation of a @see Product9 */
-case class Tuple9[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9) {
+case class Tuple9[+T1, +T2, +T3, +T4, +T5, +T6, +T7, +T8, +T9](_1:T1, _2:T2, _3:T3, _4:T4, _5:T5, _6:T6, _7:T7, _8:T8, _9:T9)
+ extends Product9[T1, T2, T3, T4, T5, T6, T7, T8, T9] {
override def toString() = {
val sb = new compat.StringBuilder
- sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append('}')
- sb.toString
+ sb.append('{').append(_1).append(',').append(_2).append(',').append(_3).append(',').append(_4).append(',').append(_5).append(',').append(_6).append(',').append(_7).append(',').append(_8).append(',').append(_9).append('}')
+ sb.toString
}
}
diff --git a/src/library/scala/xml/UnprefixedAttribute.scala b/src/library/scala/xml/UnprefixedAttribute.scala
index 8f08da3696..81d02c955f 100644
--- a/src/library/scala/xml/UnprefixedAttribute.scala
+++ b/src/library/scala/xml/UnprefixedAttribute.scala
@@ -36,10 +36,10 @@ class UnprefixedAttribute(val key: String, val value: Seq[Node], next1: MetaData
null
/**
- * Gets value of unqualified (unprefixed) attribute with given key.
+ * Gets value of unqualified (unprefixed) attribute with given key, null if not found
*
* @param key
- * @return ..
+ * @return value as Seq[Node] if key is found, null otherwise
*/
def apply(key: String): Seq[Node] =
if (key == this.key) value else next(key)
diff --git a/src/library/scala/xml/MetaData.scala b/src/library/scala/xml/MetaData.scala
index d06f2649f0..37cf9d996d 100644
--- a/src/library/scala/xml/MetaData.scala
+++ b/src/library/scala/xml/MetaData.scala
@@ -37,10 +37,12 @@ abstract class MetaData extends Iterable[MetaData] {
next.append(copy(m))
/**
- * @param s ...
- * @return ...
+ * Gets value of unqualified (unprefixed) attribute with given key, null if not found
+ *
+ * @param key
+ * @return value as Seq[Node] if key is found, null otherwise
*/
- def apply(s: String): Seq[Node]
+ def apply(key: String): Seq[Node]
/** convenience method, same as <code>apply(namespace, owner.scope, key)</code>.
*
@@ -52,6 +54,14 @@ abstract class MetaData extends Iterable[MetaData] {
final def apply(namespace: String, owner: Node, key: String): Seq[Node] =
apply(namespace, owner.scope, key)
+ /**
+ * Gets value of prefixed attribute with given key and namespace, null if not found
+ *
+ * @param uri namespace of key
+ * @param scp a namespace scp (usually of the element owning this attribute list)
+ * @param key to be looked fore
+ * @return value as Seq[Node] if key is found, null otherwise
+ */
def apply(uri:String, scp:NamespaceBinding, k:String): Seq[Node]
/**
@@ -122,25 +132,30 @@ abstract class MetaData extends Iterable[MetaData] {
/** returns Null or the next MetaData item */
def next: MetaData
- /** gets value of unqualified (unprefixed) attribute with given key */
+ /**
+ * Gets value of unqualified (unprefixed) attribute with given key, None if not found
+ *
+ * @param key
+ * @return value in Some(Seq[Node]) if key is found, None otherwise
+ */
final def get(key: String): Option[Seq[Node]] = apply(key) match {
case null => None
case x => Some(x)
}
- /** same as get(namespace, owner.scope, key) */
- final def get(namespace: String, owner: Node, key: String): Option[Seq[Node]] =
- get(namespace, owner.scope, key)
+ /** same as get(uri, owner.scope, key) */
+ final def get(uri: String, owner: Node, key: String): Option[Seq[Node]] =
+ get(uri, owner.scope, key)
+
/** gets value of qualified (prefixed) attribute with given key.
- *
- * @param namespace ...
- * @param scope ...
- * @param key ...
- * @return <code>Some(x)</code> iff ...
+ * @param uri namespace of key
+ * @param scope a namespace scp (usually of the element owning this attribute list)
+ * @param key to be looked fore
+ * @return value as Some[Seq[Node]] if key is found, None otherwise
*/
- final def get(namespace: String, scope: NamespaceBinding, key: String): Option[Seq[Node]] =
- apply(namespace, scope, key) match {
+ final def get(uri: String, scope: NamespaceBinding, key: String): Option[Seq[Node]] =
+ apply(uri, scope, key) match {
case null => None
case x => Some(x)
}